@@ -30,8 +30,8 @@
 
 #include <exo/exo-icon-chooser-model.h>
 #include <exo/exo-private.h>
-#include <exo/exo-string.h>
 #include <exo/exo-alias.h>
+#include <libxfce4util/libxfce4util.h>
 
 
 
@@ -515,6 +515,7 @@ exo_icon_chooser_model_icon_theme_changed (GtkIconTheme        *icon_theme,
       /* Skip symbolic icons since they lead to double processing */
       if (icon_name_is_symbolic (lp->data))
       {
+        g_free (lp->data);
         continue;
       }
 
@@ -553,6 +554,7 @@ exo_icon_chooser_model_icon_theme_changed (GtkIconTheme        *icon_theme,
           /* Skip symbolic icons since they lead to double processing */
           if (icon_name_is_symbolic (lp->data))
           {
+            g_free (lp->data);
             continue;
           }
 
